@@ -35,6 +35,13 @@ class TargetKind(Enum):
             "rapid_exe": TargetKind.EXECUTABLE,
         }[s]
 
+    def to_string(self):
+        return {
+            TargetKind.STATIC_LIB: "rapid_static_lib",
+            TargetKind.DYNAMIC_LIB: "rapid_dynamic_lib",
+            TargetKind.EXECUTABLE: "rapid_exe",
+        }[self.value]
+
 
 BUILD_TYPE_DEBUG = "debug"
 BUILD_TYPE_RELEASE = "release"
